#
# spec file for package python-pyerfa
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%if 0%{suse_version} <= 1500
# use the bundled ERFA in Leap <=15.X, because the system provided one is too old
%bcond_with systemlibs
%else
%bcond_without systemlibs
%endif

%define erfaversion 2.0.1
Name:           python-pyerfa
Version:        2.0.1.1
Release:        1.2
Summary:        Python bindings for ERFA
License:        BSD-3-Clause
URL:            https://github.com/liberfa/pyerfa
Source:         https://files.pythonhosted.org/packages/source/p/pyerfa/pyerfa-%{version}.tar.gz
BuildRequires:  %{python_module devel >= 3.9}
BuildRequires:  %{python_module numpy-devel >= 1.25}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest-doctestplus >= 0.7}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools_scm >= 6.2}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  pkgconfig
BuildRequires:  python-rpm-macros
%if %{with systemlibs}
BuildRequires:  pkgconfig(erfa) >= %{erfaversion}
%endif
Requires:       python-numpy >= 1.19
%python_subpackages

%description
A Python wrapper for the ERFA library (Essential Routines for
Fundamental Astronomy), a C library containing key algorithms for astronomy,
which is based on the SOFA library published by the International Astronomical
Union (IAU).  All C routines are wrapped as Numpy universal functions,
so that they can be called with scalar or array inputs.

The project is a split of astropy._erfa module, developed in the
context of Astropy project, into a standalone package.

%prep
%setup -q -n pyerfa-%{version}
%if %{with systemlibs}
rm -rf liberfa/
%endif

%build
%if %{with systemlibs}
export PYERFA_USE_SYSTEM_LIBERFA=1
%endif
%pyproject_wheel

%install
%if %{with systemlibs}
export PYERFA_USE_SYSTEM_LIBERFA=1
%endif
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitearch}

%check
%if %{with systemlibs}
# detection of non-embedded lib fails on ppc
%define skip_embedded_test -k "not test_version_with_embedded_liberfa"
%endif
%pytest_arch --pyargs erfa %{?skip_embedded_test}

%files %{python_files}
%doc README.rst
%license LICENSE.rst
%if !%{with systemlibs}
%license licenses/ERFA.rst
%endif
%{python_sitearch}/erfa
%{python_sitearch}/pyerfa-%{version}.dist-info

%changelog
* Wed Nov  8 2023 Ben Greiner <code@bnavigator.de>
- Update to 2.0.1.1
  * Ensure any non-contigous multi-dimensional inputs are recognized
    properly, so that, e.g., a non-contiguous matrix is copied as
    needed before input to the erfa functions. [gh-124]
- Release 2.0.1
  * Fix dangling pointer leading to unexpected behavior with
    ``-O3``. [gh-104]
  * PyERFA now only uses the Python limited API. [gh-94]
  * Ensure things work under python 3.12 and recent setuptools-scm.
    [gh-113]
- Use erfa 2.0.1
* Wed Apr 26 2023 Ben Greiner <code@bnavigator.de>
- Update to 2.0.0.3
  * Ensure minimum numpy version of 1.17 continues to work (for astropy LTS).
- Release 2.0.0.2
  * Fix compatibility with numpy v1.24.
  * Min setuptools_scm updated.
* Wed Jan  4 2023 Ben Greiner <code@bnavigator.de>
- Prevent Python 3.6 builds: Requires 3.7+
* Thu Dec 22 2022 Ben Greiner <code@bnavigator.de>
- Update to 2.0.0.1
  * The underlying universal functions in erfa.ufunc now work with
    an out argument also if the required output is a structured
    array. [gh-76]
* Tue May 18 2021 Ben Greiner <code@bnavigator.de>
- Update to Version 2.0.0
  * Bundled liberfa version update to v2.0.0. This includes new
    functionality, and hence pyerfa 2.0.0 cannot run with previous
    versions of liberfa.
  * erfa.dt_eraLDBODY has been corrected to ensure that the 'pv'
    entry is now of type erfa.dt_pv, so that cross-assignments with
    that dtype work correctly. [gh-74]
  * erfa_generator now also generates a test_ufunc.py file
    that runs all the C code tests on the ufuncs, thus
    verifying the code wrapping worked correctly. As part of
    that, the ability to give specific output file names has
    been removed, as it was not used. (Note: these changes
    have no effect on use of PyERFA.) [gh-71]
* Sat May 15 2021 Ben Greiner <code@bnavigator.de>
- Update to Version 1.7.3
  * Bundling updates
  * Fixed a bug that caused the output of ``rx``, ``ry``, and
  ``rz`` to be boolean rather than float for some compilers/OS.
* Fri May 14 2021 Ben Greiner <code@bnavigator.de>
- Reenable test_version but disable test_sofa_version
  * upstream fixed it for the next release in gh#liberfa/pyerfa#73
* Sun Feb 21 2021 Ben Greiner <code@bnavigator.de>
- Update to Version 1.7.2
  * bundling updates
  * The classproperty decorator is now thread-safe
- Skip python36 build: With NumPy 1.20, python36-numpy is no
  longer available in Tumbleweed (NEP 29)
* Fri Jan 15 2021 Benjamin Greiner <code@bnavigator.de>
- Use bundled ERFA in Leap
- skip python2 for leap: upstream dropped python2 support, no
  pytest doctestplus for python2
* Fri Nov 20 2020 Benjamin Greiner <code@bnavigator.de>
- Update to Version 1.7.1.1
  * Fix incorrect ``__version__`` value [gh-60].
- 1.7.1
  * Bundled liberfa version update to v1.7.1.
  * Now it is possible to build against system liberfa [gh-39].
  * Improved the setup machinery to ensure a proper
    configuration of the embedded liberfa [gh-53] (see also
    https://github.com/liberfa/erfa/pull/73).
  * Improve version testing [gh-53] (see issue gh-52 for
    rationale).
  * Reworked version management [gh-57].
  * Make pyerfa build reproducible [gh-46] (see issue gh-45
    for rationale).
  * Improved docstring titles [gh-47].
  * Most of the CI has been moved to GitHub Actions.
- Drop pyerfa-pr39-usesystemerfa.patch merged upstream
* Fri Sep 25 2020 Benjamin Greiner <code@bnavigator.de>
- skip version test to allow liberfa 1.7.1 -- gh#liberfa/pyerfa#52
* Fri Jul 10 2020 Benjamin Greiner <code@bnavigator.de>
- allow updating liberfa
* Mon Jul  6 2020 Benjamin Greiner <code@bnavigator.de>
- initial package v1.7.0
- pyerfa-pr39-usesystemerfa.patch: gh#liberfa/pyerfa#39 to be able
  to use the system provided erfa gh#liberfa/pyerfa#38
